@@ -1,10 +1,10 @@
 #ifndef PYTHONIC_INCLUDE_NUMPY_PUTMASK_HPP
 #define PYTHONIC_INCLUDE_NUMPY_PUTMASK_HPP
 
-#include "pythonic/include/utils/functor.hpp"
-#include "pythonic/include/types/ndarray.hpp"
-#include "pythonic/include/numpy/asarray.hpp"
 #include "pythonic/include/builtins/None.hpp"
+#include "pythonic/include/numpy/asarray.hpp"
+#include "pythonic/include/types/ndarray.hpp"
+#include "pythonic/include/utils/functor.hpp"
 
 PYTHONIC_NS_BEGIN
 
@@ -18,7 +18,7 @@ namespace numpy
   types::none_type putmask(E &, M const &, F const &);
 
   DEFINE_FUNCTOR(pythonic::numpy, putmask);
-}
+} // namespace numpy
 PYTHONIC_NS_END
 
 #endif
