@@ -24,7 +24,7 @@ namespace numpy
       return std::min_element(first, last);
     }
     template <class T>
-    static T value(T self, T other)
+    static bool value(T self, T other)
     {
       return self < other;
     }
@@ -37,12 +37,12 @@ namespace numpy
   }
 
   template <class E>
-  types::ndarray<long, types::array<long, E::value - 1>> argmin(E const &expr,
-                                                                long axis)
+  types::ndarray<long, types::array_tuple<long, E::value - 1>>
+  argmin(E const &expr, long axis)
   {
     return argminmax<argmin_op<E>>(expr, axis);
   }
-}
+} // namespace numpy
 PYTHONIC_NS_END
 
 #endif
