@@ -8,11 +8,10 @@ from pythran.config import cfg
 from pythran.cxxgen import PythonModule, Include, Line, Statement
 from pythran.cxxgen import FunctionBody, FunctionDeclaration, Value, Block
 from pythran.cxxgen import ReturnStatement
-from pythran.dist import PythranExtension, PythranBuildExt
+from pythran.errors import PythranCompileError
 from pythran.middlend import refine, mark_unexported_functions
 from pythran.passmanager import PassManager
 from pythran.tables import pythran_ward
-from pythran.types import tog
 from pythran.types.type_dependencies import pytype_to_deps
 from pythran.types.conversion import pytype_to_ctype
 from pythran.spec import load_specfile, Spec
@@ -22,14 +21,7 @@ from pythran.version import __version__
 from pythran.utils import cxxid
 import pythran.frontend as frontend
 
-from datetime import datetime
-from distutils.errors import CompileError
-from distutils import sysconfig
-try:
-    # `numpy.distutils is deprecated, may not be present, or broken
-    from numpy.distutils.core import setup
-except Exception:
-    from distutils.core import setup
+import sysconfig
 
 from tempfile import mkdtemp, NamedTemporaryFile
 import gast as ast
@@ -60,8 +52,8 @@ def _extract_specs_dependencies(specs):
         # for each argument
         for t in signature:
             deps.update(pytype_to_deps(t))
-    # Keep "include" first
-    return sorted(deps, key=lambda x: "include" not in x)
+
+    return sorted(deps)
 
 
 def _parse_optimization(optimization):
@@ -163,6 +155,7 @@ def generate_cxx(module_name, code, specs=None, optimizations=None,
         mod = Generable(content)
 
         def error_checker():
+            from pythran.types import tog
             tog.typecheck(ir)
 
     else:
@@ -172,6 +165,7 @@ def generate_cxx(module_name, code, specs=None, optimizations=None,
             specs = Spec(specs, {})
 
         def error_checker():
+            from pythran.types import tog
             types = tog.typecheck(ir)
             check_specs(specs, types)
 
@@ -183,8 +177,7 @@ def generate_cxx(module_name, code, specs=None, optimizations=None,
         else:
             code_bytes = code.encode('ascii', 'ignore')
         metainfo = {'hash': hashlib.sha256(code_bytes).hexdigest(),
-                    'version': __version__,
-                    'date': datetime.now()}
+                    'version': __version__}
 
         mod = PythonModule(module_name, docstrings, metainfo)
         mod.add_to_includes(
@@ -284,15 +277,65 @@ def generate_cxx(module_name, code, specs=None, optimizations=None,
                 docstring
             )
 
+        if specs.ufuncs:
+            mod.add_to_includes(
+                Include("pythonic/include/types/numpy_ufunc.hpp"),
+            )
+
+        for function_name, signatures in specs.ufuncs.items():
+            internal_func_name = cxxid(function_name)
+
+            for signature in signatures:
+                arguments_types = [pytype_to_ctype(t) for t in signature]
+                numpy_types = ['pythonic::c_type_to_numpy_type<{}>::value'.format(t) for t in
+                               arguments_types]
+                arguments_names = has_argument(ir, function_name)
+                arguments = [n for n, _ in
+                             zip(arguments_names, arguments_types)]
+                name_fmt = pythran_ward + "{0}::{1}::type{2}"
+                args_list = ", ".join(arguments_types)
+                specialized_fname = name_fmt.format(module_name,
+                                                    internal_func_name,
+                                                    "<{0}>".format(args_list)
+                                                    if arguments_names else "")
+                result_type = "typename %s::result_type" % specialized_fname
+                numpy_result_type = 'pythonic::c_type_to_numpy_type<{}>::value'.format(result_type)
+                numpy_types.append(numpy_result_type)
+
+                mod.add_ufunc(
+                    FunctionBody(
+                        FunctionDeclaration(
+                            Value(result_type, function_name),
+                            [Value(t, a)
+                             for t, a in zip(arguments_types, arguments)]),
+                        Block([ReturnStatement("{0}()({1})".format(
+                            warded(module_name, internal_func_name),
+                            ', '.join(arguments)))])
+                    ),
+                    function_name,
+                    pythran_ward + module_name + "::" + internal_func_name,
+                    arguments_types + [result_type],
+                    numpy_types
+                )
+
+    return mod, error_checker
     return mod, error_checker
 
 
 def compile_cxxfile(module_name, cxxfile, output_binary=None, **kwargs):
     '''c++ file -> native module
     Return the filename of the produced shared library
-    Raises CompileError on failure
+    Raises PythranCompileError on failure
 
     '''
+    # local import so that we don't depend on setuptools for the code generation
+    # part
+    from pythran.dist import PythranExtension, PythranBuildExt
+    try:
+        # `numpy.distutils is deprecated, may not be present, or broken
+        from numpy.distutils.core import setup
+    except Exception:
+        from setuptools import setup
 
     builddir = mkdtemp()
     buildtmp = mkdtemp()
@@ -315,7 +358,7 @@ def compile_cxxfile(module_name, cxxfile, output_binary=None, **kwargs):
                            '--build-temp', buildtmp]
               )
     except SystemExit as e:
-        raise CompileError(str(e))
+        raise PythranCompileError(str(e))
 
     def copy(src_file, dest_file):
         # not using shutil.copy because it fails to copy stat across devices
@@ -424,7 +467,7 @@ def compile_pythrancode(module_name, pythrancode, specs=None,
                                           str(module),
                                           output_binary=output_file,
                                           **kwargs)
-        except CompileError:
+        except PythranCompileError:
             logger.warning("Compilation error, "
                            "trying hard to find its origin...")
             error_checker()
@@ -517,7 +560,7 @@ def import_pythranfile(pythranpath, **kwargs):
 
 def test_compile():
     '''Simple passthrough compile test.
-    May raises CompileError Exception.
+    May raises PythranCompileError Exception.
 
     '''
     code = '''
